package csci1902.hw3;

import junit.framework.TestCase;
import java.awt.Point;

/**
 * Tests for the FoodSource class.
 * @author Michael Ekstrand <ekstrand@cs.umn.edu>
 *
 */
public class FoodSourceTest extends TestCase {
    private World world;
    private FoodSource entity;
    
    /**
     * Set up each test.  This creates a 10x10 world, and creates a new food
     * source at (5,5) with that world and a food quantity of 10.
     */
    protected void setUp() {
        world = new World(10, 10);
        entity = new FoodSource(world, new Point(5,5), 10);
    }
    
    /**
     * Test the initial state of a food source.  This makes sure that it has the
     * correct food quantity (10, in our case), and that it has the correct
     * world.
     */
    public void testInitialState() {
        assertEquals(10, entity.getFoodUnits());
        assertSame(world, entity.getWorld());
    }
    
    /**
     * Test to make sure that a food source claims food source capabilities.
     */
    public void testIsFoodSource() {
        assertTrue(entity.isFoodSource());
    }
    
    /**
     * Test the food collection behavior of a food source.  This makes sure
     * that it allows food to be collected, and that its food supply is
     * decremented accordingly.
     */
    public void testCollectFood() {
        assertEquals(3, entity.collectFood(3));
        assertEquals(10, entity.getFoodUnits());
        entity.update();
        assertEquals(7, entity.getFoodUnits());
    }
    
    /**
     * Tests the behavior of a food source as its last food is collected.  This
     * makes sure that it only allows its remaining capacity to be collected,
     * and that it dies when its supply is exhausted.
     */
    public void testCollectLastFood() {
        assertEquals(10, entity.collectFood(12));
        assertTrue(entity.isAlive());
        assertTrue(entity.isDying());
        entity.update();
        assertEquals(0, entity.getFoodUnits());
        assertFalse(entity.isAlive());
    }
}
